<?php

class Controller_App extends Controller_Base
{
	protected $auth;
	public $user;

	/**
	 *
	 */
	public function before()
	{
		parent::before();


		$this->_init_auth();
		$this->_init_user();
		$this->_init_notice();
		$this->_init_template();
	}



	/**
	 * Check if user is logged in
	 */
	public function is_logged_in()
	{
		return isset($this->user);
	}


	/**
	 * Require user authentication for a page
	 */
	public function require_auth()
	{
		if (! $this->is_logged_in())
		{
			$this->redirect('/', 'info', 'You must be logged in to do that.');
		}
	}


	/**
	 * Init auth package and current user
	 */
	private function _init_auth()
	{
		$this->auth = Auth::instance();
	}

	private function _init_user()
	{
		if ($this->auth->check())
		{
			$user_id = $this->auth->get_user_id();
			$this->user = Model_User::get_by_id($user_id);
		}
		else
		{
			$this->user = null;
		}
	}

	private function _init_notice()
	{
		foreach (array('error', 'success', 'info') as $type)
		{
			$notice = Session::get_flash($type);

			if (isset($notice))
			{
				$this->template->notice = (object) array('type' => $type, 'message' => $notice);
				break;
			}
		}
	}

	private function _init_template()
	{
		// set global template variables
		if (isset($this->template))
		{
			$this->template->set_global('user', $this->user, false);
		}

		// enviroment specific
		switch (Fuel::$env)
		{
			case \Fuel::DEVELOPMENT:
				//Casset::js('evelog_dev.js');
				break;

			default:
				//Casset::js('evelog.js');
			
		}
	}

}