<?php

class Controller_Profile extends Controller_App
{
	public function get_view($profile_url)
	{
		$profile = $this->_get_user($profile_url);

		$this->template->sidebar = View::forge('profile/sidebar', array(
			'profile' => $profile,
			'posts'   => $profile->get_articles(),
		));

		$this->template->body    = View::forge('profile/articles', array(
			'articles' => $profile->get_articles(),
		), false);
		
	}


	public function get_article($profile_url, $article_url)
	{
		$profile    = $this->_get_user($profile_url);
		$article = $profile->get_article_by_url($article_url);

		if (! $article)
		{
			throw new HttpNotFoundException;
		}

		$this->template->sidebar = View::forge('profile/sidebar', array(
			'profile'  => $profile,
			'posts'    => $profile->get_articles(),
		));

		$this->template->body    = View::forge('profile/article', array(
			'article' => $article,
		), false);
	}



	public function get_rate($profile_url, $article_url, $rating) //The article comes through
	{
		$profile    = $this->_get_user($profile_url); //Gets current users profile
		$article = $profile->get_article_by_url($article_url); //Gets articles URL

		$this->require_auth(); //Makes sure the user is logged in
		
		// has user already rated?
		if (Model_Rating::rating_exists($profile, $article))
		{
			$this->redirect(Uri::base(false).$profile->url.'/'.$article->url, 'error', 'You have already rated this article');
		}

		$article->add_rating($profile->id, $rating);
		//Model_Rating::rate($profile, $article, $rating);

		//Redirects user back to the article they rated
		$this->redirect(Uri::create("{$profile->url}/{$article->url}"), 'success', 'Your rating has been recieved');
	}



	private function _get_user($profile_url)
	{
		$user = Model_User::get_by_url($profile_url);

		if (! $user)
		{
			throw new HttpNotFoundException;
		}

		return $user;
	}

	public function get_edit($article_id)
	{
		$article = Model_Article::get_by_id($article_id);

		if(isset($this->user->id))
		{
			if($article->user_id != $this->user->id)
			{
				$this->redirect('/', 'error', 'You can only edit your own articles');
			}
			
			$this->template->body = View::forge('profile/edit', array(
				'article' => $article,
			));
		}else
		{
			$this->redirect('/', 'error', 'You can only edit your own articles');	
		}
	}
}