<?php

class Model_Article extends \Orm\Model
{
	//protected static $_table_name = 'articles';

	protected static $_properties = array(
		'id',
		'user_id',
		'url',
		'title',
		'content',
		'views',
		'created_at',
		'updated_at',
		'rating',
	);


	// belongs_to Model_User
	protected static $_belongs_to = array('user');


	protected static $_observers = array(
		'Orm\\Observer_CreatedAt' => array(
			'events' => array('before_insert'),
			'mysql_timestamp' => false,
			'property' => 'created_at',
		),
		'Orm\\Observer_UpdatedAt' => array(
			'events' => array('before_save'),
			'mysql_timestamp' => false,
			'property' => 'updated_at',
		),
		'Orm\\Observer_Slug' => array(
			'events' => array('before_insert', 'before_update'),
			'source' => 'title',
			'property' => 'url',
		),
	);

	public function url()
	{
		return $this->user->url() . '/' . $this->url;
	}

	public function rate_url($rating)
	{
		return $this->url() . '/rate/' . $rating;
	}

	public function get_rating()
	{
		return Model_Rating::get_article_rating($this->id);
	}

	public function add_rating($profile_id, $rating)
	{
		$rate = Model_Rating::forge(array(
			'user_id'    => $profile_id,
			'article_id' => $this->id,
			'rating'     => $rating,
		));
		$rate->save();

		$avg_rating = $this->get_rating();
		$this->set_rating($avg_rating);

		return true;
	}

	public function set_rating($rating)
	{
		$this->rating = $rating;
		$this->save();
	}

	public function total_ratings()
	{
		return Model_Rating::total_ratings($this->id);
	}

	public function date($format = "m/d/Y h:m a")
	{
		return date($format, $this->created_at);
	}

	public static function get_by_id($article_id)
	{
		return static::query()->where('id', $article_id)->get_one();
	}

	public static function get_recent()
	{
		return static::query()->order_by('created_at', 'desc')->limit(10)->get();
	}

	public static function get_user_articles($user_id, $limit = 10)
	{
		return static::query()->where('user_id', $user_id)->order_by('created_at', 'desc')->limit($limit)->get();
	}

	public static function get_user_article($user_id, $article_url)
	{
		$article = static::query()->where('user_id', $user_id)->where('url', $article_url)->get_one();
		$article->views = $article->views + 1;
		$article->save();
		return $article;
	}

	public static function post_article($title, $content, $user_id)
	{
		$article = static::forge(array(
			'user_id' => $user_id,
			'title'   => $title,
			'content' => $content,
		));

		return $article->save() ? $article : null;
	}

	public static function post_update($title, $content, $article_id, $user_id)
	{	
		$article = static::query()->where('id', $article_id)->get_one();

		if(! $article->user_id == $user_id)
		{
			return null;
		}
		
		$article->set(array(
			'title'   => $title,
			'content' => $content,
		));

		return $article->save() ? $article : null;
	}

}