
<?php

class Model_User extends \Orm\Model
{
	protected static $_table_name = 'users';

	protected static $_properties = array(
		'id',
		'username',
		'url',
		'password',
		'group',
		'email',
		'first_name',
		'last_name',
		'last_login',
		'login_hash',
		'profile_fields',
		'created_at',
		'updated_at',
	);

	// has_many Model_Article
	protected static $_has_many = array('article', 'rating', 'featuredarticles');

	protected static $_observers = array(
		'Orm\\Observer_CreatedAt' => array(
			'events' => array('before_insert'),
			'mysql_timestamp' => true,
			'property' => 'created_at',
		),
		'Orm\\Observer_UpdatedAt' => array(
			'events' => array('before_save'),
			'mysql_timestamp' => true,
			'property' => 'updated_at',
		),
		'Orm\\Observer_Slug' => array(
			'events' => array('before_insert', 'before_update'),
			'source' => 'username',
			'property' => 'url',
		),
	);

	public function url()
	{
		return $this->url;
	}


	public function get_articles($limit = 10)
	{
		return Model_Article::get_user_articles($this->id, $limit);
	}
	
	public function get_article_by_url($article_url)
	{
		return Model_Article::get_user_article($this->id, $article_url);
	}

	public static function get_featured()
	{
		return static::query()->order_by('created_at', 'asc')->get();
	}

	public static function username_exists($username)
	{
		$total = static::query()->where('username', $username)->count();
		return ($total > 0);
	}

	public static function get_by_id($user_id)
	{
		return static::query()->where('id', $user_id)->get_one();
	}

	public static function get_by_url($profile_url)
	{
		return static::query()->where('url', $profile_url)->get_one();
		
	}

	public static function create_user($email, $password)
	{
		$user = static::forge(array(
			'email'    => $email,
			'password' => $password,
		));
		return $user->save() ? $user : null;
	}

}